# Django adapter for Aurora DSQL

This package is parked by Amazon Web Services. 
An open source package will be made available at https://github.com/awslabs/aurora-dsql-django.
Stay tuned for updates! 
